function [ret,x0,str,ts,xts]=regdesat(t,x,u,flag);
%REGDESAT	is the M-file description of the SIMULINK system named REGDESAT.
%	The block-diagram can be displayed by typing: REGDESAT.
%
%	SYS=REGDESAT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDESAT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDESAT with a FLAG of zero:
%	[SIZES]=REGDESAT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1269,981])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     'tsim*1')
set_param(sys,'Min step size', 'tsim/20000')
set_param(sys,'Max step size', 'tsim/2000')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','NANOSATELLITE CASAA-SAT'])
set_param([sys,'/','NANOSATELLITE CASAA-SAT'],...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[620,5,625,10])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\n\ndes angles ( degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;gcf;'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[265,745,465,811])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\n\nvitesses angulaires (degrs/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;gcf'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,830,490,891])

add_block('built-in/Note',[sys,'/',['Vecteur ',13,'Commande',13,'du second membre',13,'de l''quation d''tat']])
set_param([sys,'/',['Vecteur ',13,'Commande',13,'du second membre',13,'de l''quation d''tat']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[615,115,620,120])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir les courbes\n\nvitesse roue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;gcf'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[750,750,940,811])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir les courbes\ncouple \nperturbateurs (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_pert);grid;gcf'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[760,840,935,901])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[500,815,730,901])

add_block('built-in/Note',[sys,'/',[' 3 + 4 + 5  : fonctionnement parfait   ',13,'']])
set_param([sys,'/',[' 3 + 4 + 5  : fonctionnement parfait   ',13,'']],...
		'position',[740,570,745,575])

add_block('built-in/Note',[sys,'/','1 + 3 + 4 : fonctionnement parfait'])
set_param([sys,'/','1 + 3 + 4 : fonctionnement parfait'],...
		'position',[775,515,780,520])

add_block('built-in/Note',[sys,'/','1 + 2 + 3 + 4 + 5 : fonctionnement parfait'])
set_param([sys,'/','1 + 2 + 3 + 4 + 5 : fonctionnement parfait'],...
		'position',[750,545,755,550])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[695,352,730,378])

add_block('built-in/Note',[sys,'/','U'])
set_param([sys,'/','U'],...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[630,315,635,320])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Weight','bold',...
		'Font Size',16,...
		'inputs','++++',...
		'position',[610,202,655,528])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[320,438,1023,1003])


%     Subsystem  'Subsystem5/Subsystem'.

new_system([sys,'/','Subsystem5/Subsystem'])
set_param([sys,'/','Subsystem5/Subsystem'],'Location',[254,259,1259,858])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']])
set_param([sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']],...
		'hide name',0,...
		'position',[540,95,545,100])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/wo phi'])
set_param([sys,'/','Subsystem5/Subsystem/wo phi'],...
		'hide name',0,...
		'position',[275,215,280,220])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/psi prime'])
set_param([sys,'/','Subsystem5/Subsystem/psi prime'],...
		'hide name',0,...
		'position',[295,175,300,180])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/teta prime'])
set_param([sys,'/','Subsystem5/Subsystem/teta prime'],...
		'hide name',0,...
		'position',[280,85,285,90])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/phi prime'])
set_param([sys,'/','Subsystem5/Subsystem/phi prime'],...
		'hide name',0,...
		'position',[270,45,275,50])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant'])
set_param([sys,'/','Subsystem5/Subsystem/Constant'],...
		'hide name',0,...
		'Value','vitesse_rotation',...
		'position',[235,119,335,141])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum1'])
set_param([sys,'/','Subsystem5/Subsystem/Sum1'],...
		'hide name',0,...
		'position',[365,107,385,138])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum'])
set_param([sys,'/','Subsystem5/Subsystem/Sum'],...
		'hide name',0,...
		'position',[365,70,385,90])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum2'])
set_param([sys,'/','Subsystem5/Subsystem/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[360,188,385,232])

add_block('built-in/Mux',[sys,'/','Subsystem5/Subsystem/Mux'])
set_param([sys,'/','Subsystem5/Subsystem/Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[460,89,490,191])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain'])
set_param([sys,'/','Subsystem5/Subsystem/Gain'],...
		'hide name',0,...
		'Gain','vitesse_rotation',...
		'position',[90,232,115,258])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux'])
set_param([sys,'/','Subsystem5/Subsystem/Demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[105,58,150,172])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_1'])
set_param([sys,'/','Subsystem5/Subsystem/in_1'],...
		'hide name',0,...
		'position',[55,105,75,125])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux1'])
set_param([sys,'/','Subsystem5/Subsystem/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[150,207,200,283])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_2'])
set_param([sys,'/','Subsystem5/Subsystem/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[50,235,70,255])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant3'])
set_param([sys,'/','Subsystem5/Subsystem/Constant3'],...
		'hide name',0,...
		'Value','3*(Ir-Il)',...
		'position',[60,291,255,329])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant2'])
set_param([sys,'/','Subsystem5/Subsystem/Constant2'],...
		'hide name',0,...
		'Value','3*(Il-It)',...
		'position',[65,371,260,409])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum5'])
set_param([sys,'/','Subsystem5/Subsystem/Sum5'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[775,252,800,303])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']])
set_param([sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[480,5,485,10])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem/Outport'])
set_param([sys,'/','Subsystem5/Subsystem/Outport'],...
		'position',[835,270,855,290])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/E. M'])
set_param([sys,'/','Subsystem5/Subsystem/E. M'],...
		'position',[895,265,900,270])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']])
set_param([sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']],...
		'position',[660,145,665,150])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem/MATLAB Fcn'],...
		'MATLAB Fcn','cinetic(Asat,u)',...
		'Output Width','1',...
		'position',[560,123,620,157])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']])
set_param([sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']],...
		'position',[635,320,640,325])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product1'])
set_param([sys,'/','Subsystem5/Subsystem/Product1'],...
		'position',[270,239,285,266])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product'])
set_param([sys,'/','Subsystem5/Subsystem/Product'],...
		'position',[360,244,385,291])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product2'])
set_param([sys,'/','Subsystem5/Subsystem/Product2'],...
		'position',[375,326,390,364])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum4'])
set_param([sys,'/','Subsystem5/Subsystem/Sum4'],...
		'hide name',0,...
		'position',[520,292,545,343])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product3'])
set_param([sys,'/','Subsystem5/Subsystem/Product3'],...
		'position',[425,323,455,412])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain1'])
set_param([sys,'/','Subsystem5/Subsystem/Gain1'],...
		'Gain','-1/2',...
		'position',[615,305,675,335])
add_line([sys,'/','Subsystem5/Subsystem'],[390,210;430,210;430,175;455,175])
add_line([sys,'/','Subsystem5/Subsystem'],[390,125;430,125;430,140;455,140])
add_line([sys,'/','Subsystem5/Subsystem'],[390,80;405,80;405,105;455,105])
add_line([sys,'/','Subsystem5/Subsystem'],[205,220;355,220])
add_line([sys,'/','Subsystem5/Subsystem'],[155,155;250,155;250,200;355,200])
add_line([sys,'/','Subsystem5/Subsystem'],[340,130;360,130])
add_line([sys,'/','Subsystem5/Subsystem'],[155,115;360,115])
add_line([sys,'/','Subsystem5/Subsystem'],[120,245;145,245])
add_line([sys,'/','Subsystem5/Subsystem'],[205,270;220,270;220,85;360,85])
add_line([sys,'/','Subsystem5/Subsystem'],[155,75;360,75])
add_line([sys,'/','Subsystem5/Subsystem'],[80,115;100,115])
add_line([sys,'/','Subsystem5/Subsystem'],[75,245;85,245])
add_line([sys,'/','Subsystem5/Subsystem'],[260,310;335,310;335,280;355,280])
add_line([sys,'/','Subsystem5/Subsystem'],[315,220;315,335;370,335])
add_line([sys,'/','Subsystem5/Subsystem'],[550,320;610,320])
add_line([sys,'/','Subsystem5/Subsystem'],[680,320;750,320;750,290;770,290])
add_line([sys,'/','Subsystem5/Subsystem'],[805,280;830,280])
add_line([sys,'/','Subsystem5/Subsystem'],[495,140;555,140])
add_line([sys,'/','Subsystem5/Subsystem'],[625,140;720,140;720,265;770,265])
add_line([sys,'/','Subsystem5/Subsystem'],[205,245;265,245])
add_line([sys,'/','Subsystem5/Subsystem'],[240,245;240,260;265,260])
add_line([sys,'/','Subsystem5/Subsystem'],[290,255;355,255])
add_line([sys,'/','Subsystem5/Subsystem'],[330,335;330,355;370,355])
add_line([sys,'/','Subsystem5/Subsystem'],[395,345;420,345])
add_line([sys,'/','Subsystem5/Subsystem'],[265,390;420,390])
add_line([sys,'/','Subsystem5/Subsystem'],[390,270;480,270;480,305;515,305])
add_line([sys,'/','Subsystem5/Subsystem'],[460,370;505,370;515,330])
set_param([sys,'/','Subsystem5/Subsystem'],...
		'Mask Display','ENERGIE')


%     Finished composite block 'Subsystem5/Subsystem'.

set_param([sys,'/','Subsystem5/Subsystem'],...
		'hide name',0,...
		'position',[165,302,270,338])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux3'])
set_param([sys,'/','Subsystem5/Demux3'],...
		'hide name',0,...
		'outputs','3',...
		'position',[75,68,115,152])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace12'])
set_param([sys,'/','Subsystem5/To Workspace12'],...
		'hide name',0,...
		'mat-name','cply',...
		'buffer','points_trace',...
		'position',[160,102,210,118])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux'])
set_param([sys,'/','Subsystem5/Demux'],...
		'hide name',0,...
		'outputs','[3,3]',...
		'position',[60,193,105,377])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux2'])
set_param([sys,'/','Subsystem5/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[180,198,220,282])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace11'])
set_param([sys,'/','Subsystem5/To Workspace11'],...
		'hide name',0,...
		'mat-name','vitesses',...
		'buffer','2000',...
		'position',[180,157,230,173])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/in_1'],...
		'position',[15,100,35,120])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_2'])
set_param([sys,'/','Subsystem5/in_2'],...
		'Port','2',...
		'position',[15,275,35,295])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace'])
set_param([sys,'/','Subsystem5/To Workspace'],...
		'mat-name','cpl_total',...
		'buffer','points_trace',...
		'position',[145,27,195,43])

add_block('built-in/Clock',[sys,'/','Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Clock'],...
		'position',[120,505,140,525])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace7'])
set_param([sys,'/','Subsystem5/To Workspace7'],...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[320,312,370,328])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace10'])
set_param([sys,'/','Subsystem5/To Workspace10'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[305,202,355,218])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace9'])
set_param([sys,'/','Subsystem5/To Workspace9'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[305,262,355,278])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace8'])
set_param([sys,'/','Subsystem5/To Workspace8'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[305,232,355,248])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain7'])
set_param([sys,'/','Subsystem5/Gain7'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[250,197,285,223])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain8'])
set_param([sys,'/','Subsystem5/Gain8'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[250,227,285,253])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain9'])
set_param([sys,'/','Subsystem5/Gain9'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[250,257,285,283])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace6'])
set_param([sys,'/','Subsystem5/To Workspace6'],...
		'hide name',0,...
		'mat-name','cplx',...
		'buffer','points_trace',...
		'position',[160,72,210,88])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace13'])
set_param([sys,'/','Subsystem5/To Workspace13'],...
		'hide name',0,...
		'mat-name','cplz',...
		'buffer','points_trace',...
		'position',[160,132,210,148])


%     Subsystem  ['Subsystem5/Auto-Scale',13,'Graph'].

new_system([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Subsystem5/Auto-Scale',13,'Graph/x']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem5/Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],[90,65;125,65])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Entries','6080\/-0.2\/0.2\/2000\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Subsystem5/Auto-Scale',13,'Graph'].

set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'position',[310,345,340,385])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace2'])
set_param([sys,'/','Subsystem5/To Workspace2'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[605,407,655,423])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/To Workspace3'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[600,437,650,453])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace4'])
set_param([sys,'/','Subsystem5/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[605,467,655,483])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain10'])
set_param([sys,'/','Subsystem5/Gain10'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[505,402,540,428])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain11'])
set_param([sys,'/','Subsystem5/Gain11'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[505,432,540,458])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain12'])
set_param([sys,'/','Subsystem5/Gain12'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[505,462,540,488])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux1'])
set_param([sys,'/','Subsystem5/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[415,403,455,487])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace5'])
set_param([sys,'/','Subsystem5/To Workspace5'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[360,507,410,523])

add_block('built-in/Note',[sys,'/',['Subsystem5/Conversion en',13,'degrs']])
set_param([sys,'/',['Subsystem5/Conversion en',13,'degrs']],...
		'position',[525,485,530,490])


%     Subsystem  'Subsystem5/Subsystem2'.

new_system([sys,'/','Subsystem5/Subsystem2'])
set_param([sys,'/','Subsystem5/Subsystem2'],'Location',[250,369,853,604])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem2/Constant'])
set_param([sys,'/','Subsystem5/Subsystem2/Constant'],...
		'Value','0.5*pi/180',...
		'position',[55,128,165,162])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem5/Subsystem2/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem5/Subsystem2/Relational',13,'Operator']],...
		'Operator','<',...
		'position',[200,71,225,169])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/Subsystem2/To Workspace2'])
set_param([sys,'/','Subsystem5/Subsystem2/To Workspace2'],...
		'hide name',0,...
		'mat-name','angle_min',...
		'buffer','points_trace',...
		'position',[245,30,340,60])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem2/in_1'])
set_param([sys,'/','Subsystem5/Subsystem2/in_1'],...
		'position',[35,85,55,105])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem2/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem2/MATLAB Fcn'],...
		'MATLAB Fcn','norm(u,inf)',...
		'Output Width','1',...
		'position',[100,78,160,112])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem5/Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem5/Subsystem2/Stop Simulation'],...
		'position',[455,103,555,137])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem2/Gain9'])
set_param([sys,'/','Subsystem5/Subsystem2/Gain9'],...
		'hide name',0,...
		'Gain','1-desat',...
		'position',[350,107,385,133])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem2/Ce gain vaut 0 en dsaturation',13,'donc dconnecte le stop',13,'qui ne fonctionne qu''en rgime',13,'continu de rgulation']])
set_param([sys,'/',['Subsystem5/Subsystem2/Ce gain vaut 0 en dsaturation',13,'donc dconnecte le stop',13,'qui ne fonctionne qu''en rgime',13,'continu de rgulation']],...
		'position',[300,155,305,160])
add_line([sys,'/','Subsystem5/Subsystem2'],[165,95;195,95])
add_line([sys,'/','Subsystem5/Subsystem2'],[170,145;195,145])
add_line([sys,'/','Subsystem5/Subsystem2'],[60,95;95,95])
add_line([sys,'/','Subsystem5/Subsystem2'],[180,95;180,45;240,45])
add_line([sys,'/','Subsystem5/Subsystem2'],[230,120;345,120])
add_line([sys,'/','Subsystem5/Subsystem2'],[390,120;450,120])
set_param([sys,'/','Subsystem5/Subsystem2'],...
		'Mask Display','STOP SUR ANGLE\n\nMINIMUM')


%     Finished composite block 'Subsystem5/Subsystem2'.

set_param([sys,'/','Subsystem5/Subsystem2'],...
		'position',[485,327,650,373])
add_line([sys,'/','Subsystem5'],[120,140;155,140])
add_line([sys,'/','Subsystem5'],[120,110;155,110])
add_line([sys,'/','Subsystem5'],[120,80;155,80])
add_line([sys,'/','Subsystem5'],[110,330;160,330])
add_line([sys,'/','Subsystem5'],[150,330;150,445;410,445])
add_line([sys,'/','Subsystem5'],[275,320;315,320])
add_line([sys,'/','Subsystem5'],[110,240;175,240])
add_line([sys,'/','Subsystem5'],[140,240;140,165;175,165])
add_line([sys,'/','Subsystem5'],[140,240;140,310;160,310])
add_line([sys,'/','Subsystem5'],[40,110;70,110])
add_line([sys,'/','Subsystem5'],[40,285;55,285])
add_line([sys,'/','Subsystem5'],[150,365;305,365])
add_line([sys,'/','Subsystem5'],[50,110;50,35;140,35])
add_line([sys,'/','Subsystem5'],[145,515;355,515])
add_line([sys,'/','Subsystem5'],[225,210;245,210])
add_line([sys,'/','Subsystem5'],[290,210;300,210])
add_line([sys,'/','Subsystem5'],[225,240;245,240])
add_line([sys,'/','Subsystem5'],[290,240;300,240])
add_line([sys,'/','Subsystem5'],[225,270;245,270])
add_line([sys,'/','Subsystem5'],[290,270;300,270])
add_line([sys,'/','Subsystem5'],[460,415;500,415])
add_line([sys,'/','Subsystem5'],[545,415;600,415])
add_line([sys,'/','Subsystem5'],[460,445;500,445])
add_line([sys,'/','Subsystem5'],[545,445;595,445])
add_line([sys,'/','Subsystem5'],[460,475;500,475])
add_line([sys,'/','Subsystem5'],[545,475;600,475])
add_line([sys,'/','Subsystem5'],[370,445;370,350;480,350])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','SORTIES DES VARIABLES\n\nCOUPLE TOTAL\n\nENERGIE')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[720,190,940,305])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[293,692,793,906])

add_block('built-in/Inport',[sys,'/','Subsystem1/Inport'])
set_param([sys,'/','Subsystem1/Inport'],...
		'position',[50,80,70,100])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],'Location',[-62,107,1205,663])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1025,53,1055,157])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[835,58,980,82])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[835,93,980,117])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[835,128,980,152])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[935,165,940,170])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1015,213,1045,317])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[825,218,970,242])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[825,253,970,277])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[825,288,970,312])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','+++',...
		'position',[1130,214,1165,316])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'position',[1200,255,1220,275])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']],...
		'position',[560,385,565,390])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']],...
		'position',[565,285,570,290])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[170,333,315,357])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[170,298,315,322])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[170,263,315,287])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[360,258,390,362])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']],...
		'position',[190,380,195,385])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[50,450,70,470])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[95,380,140,540])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']],...
		'position',[175,455,180,460])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']],...
		'position',[170,415,175,420])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']],...
		'position',[165,495,170,500])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']],...
		'inputs','3',...
		'position',[225,424,265,506])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[290,428,490,502])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[580,256,625,474])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[680,348,740,382])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[465,40,470,45])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[285,216,290,221])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[25,380,70,540])

add_block('built-in/To Workspace',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[935,410,1055,440])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[415,285,530,335])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[810,408,870,442])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[730,247,735,252])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[920,369,925,374])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[840,352,875,378])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1060,105;1115,105;1125,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1170,265;1195,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,300;1010,300])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1050,265;1125,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,265;1010,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,230;1010,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,140;1020,140])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,105;1020,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,70;1020,70])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,345;355,345])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,310;355,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,275;355,275])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[395,310;410,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[535,310;575,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[270,465;285,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,440;220,440])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,480;205,480;205,465;220,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,520;185,520;185,490;220,490])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[75,460;90,460])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[495,465;510,465;510,420;575,420])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[630,365;675,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[745,365;775,365;775,425;805,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[875,425;930,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[775,365;835,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[880,365;1095,365;1095,300;1125,300])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[100,62,230,118])

add_block('built-in/Gain',[sys,'/','Subsystem1/Gain3'])
set_param([sys,'/','Subsystem1/Gain3'],...
		'hide name',0,...
		'position',[270,77,305,103])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[410,80,430,100])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/To Workspace10'])
set_param([sys,'/','Subsystem1/To Workspace10'],...
		'hide name',0,...
		'mat-name','cpl_pert',...
		'buffer','points_trace',...
		'position',[375,50,480,70])
add_line([sys,'/','Subsystem1'],[235,90;265,90])
add_line([sys,'/','Subsystem1'],[310,90;405,90])
add_line([sys,'/','Subsystem1'],[75,90;95,90])
add_line([sys,'/','Subsystem1'],[340,90;340,60;370,60])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','3 - PERTURBATIONS\n\nFournir la direction\ndu moment rsiduel')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[95,369,445,441])

add_block('built-in/Note',[sys,'/','Tous les couples intervenants'])
set_param([sys,'/','Tous les couples intervenants'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[280,150,285,155])

add_block('built-in/Gain',[sys,'/','Gain9'])
set_param([sys,'/','Gain9'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','desat',...
		'position',[510,312,545,338])

add_block('built-in/Gain',[sys,'/','Gain6'])
set_param([sys,'/','Gain6'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[500,232,535,258])

add_block('built-in/Gain',[sys,'/','Gain7'])
set_param([sys,'/','Gain7'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[510,392,545,418])

add_block('built-in/Gain',[sys,'/','Gain8'])
set_param([sys,'/','Gain8'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[510,472,545,498])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[45,80,1259,660])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre du couple roue',13,'dimension 1']])
set_param([sys,'/',['Subsystem/Entre du couple roue',13,'dimension 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[140,205,145,210])

add_block('built-in/Inport',[sys,'/','Subsystem/Inport'])
set_param([sys,'/','Subsystem/Inport'],...
		'position',[170,165,190,185])

add_block('built-in/Note',[sys,'/','Subsystem/Vitesse roue'])
set_param([sys,'/','Subsystem/Vitesse roue'],...
		'position',[445,205,450,210])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[420,59,525,91])

add_block('built-in/Integrator',[sys,'/','Subsystem/Integrator2'])
set_param([sys,'/','Subsystem/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[445,123,490,167])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain5'])
set_param([sys,'/','Subsystem/Gain5'],...
		'BackGround',7,...
		'Gain','1/J',...
		'position',[385,125,420,165])

add_block('built-in/Gain',[sys,'/',['Subsystem/Inversion',13,'signe1']])
set_param([sys,'/',['Subsystem/Inversion',13,'signe1']],...
		'orientation',1,...
		'ForeGround',7,...
		'position',[555,170,585,200])

add_block('built-in/Gain',[sys,'/',['Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[315,132,345,158])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain1'])
set_param([sys,'/','Subsystem/Gain1'],...
		'position',[630,293,655,327])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace6'])
set_param([sys,'/','Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[925,179,1070,211])


%     Subsystem  'Subsystem/Subsystem1'.

new_system([sys,'/','Subsystem/Subsystem1'])
set_param([sys,'/','Subsystem/Subsystem1'],'Location',[4,135,1217,1003])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Entre de la vitesse ',13,'de la roue']])
set_param([sys,'/',['Subsystem/Subsystem1/Entre de la vitesse ',13,'de la roue']],...
		'position',[1290,650,1295,655])

add_block('built-in/Product',[sys,'/','Subsystem/Subsystem1/Product2'])
set_param([sys,'/','Subsystem/Subsystem1/Product2'],...
		'inputs','4',...
		'position',[830,359,850,666])

add_block('built-in/Product',[sys,'/','Subsystem/Subsystem1/Product3'])
set_param([sys,'/','Subsystem/Subsystem1/Product3'],...
		'position',[910,291,930,424])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Subsystem1/To Workspace1'])
set_param([sys,'/','Subsystem/Subsystem1/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','couple_desat',...
		'buffer','points_trace',...
		'position',[975,434,1070,486])

add_block('built-in/To Workspace',[sys,'/',['Subsystem/Subsystem1/test ',13,'1 ou 1']])
set_param([sys,'/',['Subsystem/Subsystem1/test ',13,'1 ou 1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'mat-name','desat',...
		'buffer','1',...
		'position',[1000,497,1060,533])

add_block('built-in/Outport',[sys,'/','Subsystem/Subsystem1/out_1'])
set_param([sys,'/','Subsystem/Subsystem1/out_1'],...
		'position',[1040,350,1060,370])

add_block('built-in/Clock',[sys,'/','Subsystem/Subsystem1/Clock1'])
set_param([sys,'/','Subsystem/Subsystem1/Clock1'],...
		'hide name',0,...
		'position',[90,299,110,321])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant4'])
set_param([sys,'/','Subsystem/Subsystem1/Constant4'],...
		'hide name',0,...
		'position',[735,382,790,418])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Couple appliqu',13,'au satellite',13,'sur le tangage']])
set_param([sys,'/',['Subsystem/Subsystem1/Couple appliqu',13,'au satellite',13,'sur le tangage']],...
		'position',[1030,280,1035,285])

add_block('built-in/Gain',[sys,'/','Subsystem/Subsystem1/Gain'])
set_param([sys,'/','Subsystem/Subsystem1/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[315,108,410,132])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Couple C(t) de',13,'dsaturation']])
set_param([sys,'/',['Subsystem/Subsystem1/Couple C(t) de',13,'dsaturation']],...
		'BackGround',7,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[240,50,245,55])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/Calibrage',13,'du couple']])
set_param([sys,'/',['Subsystem/Subsystem1/Calibrage',13,'du couple']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[370,50,375,55])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/C(t)'])
set_param([sys,'/','Subsystem/Subsystem1/C(t)'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[400,140,405,145])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Subsystem1/To Workspace2'])
set_param([sys,'/','Subsystem/Subsystem1/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','couple_C',...
		'buffer','points_trace',...
		'position',[480,94,575,146])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'])
set_param([sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','liss_cpl(u,debut_desaturation,periode_orbitale)',...
		'Output Width','1',...
		'Mask Display','LISS_CPL')
set_param([sys,'/','Subsystem/Subsystem1/MATLAB Fcn6'],...
		'position',[200,103,290,137])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator3']])
set_param([sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator3']],...
		'position',[705,436,735,509])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Commutateurs commands 0  ou 1'])
set_param([sys,'/','Subsystem/Subsystem1/Commutateurs commands 0  ou 1'],...
		'position',[685,325,690,330])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant5'])
set_param([sys,'/','Subsystem/Subsystem1/Constant5'],...
		'hide name',0,...
		'position',[750,617,805,653])

add_block('built-in/Sum',[sys,'/','Subsystem/Subsystem1/Sum1'])
set_param([sys,'/','Subsystem/Subsystem1/Sum1'],...
		'hide name',0,...
		'position',[620,169,645,211])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem1/in_3'])
set_param([sys,'/','Subsystem/Subsystem1/in_3'],...
		'Port','2',...
		'position',[215,190,235,210])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Entre couple roue classique'])
set_param([sys,'/','Subsystem/Subsystem1/Entre couple roue classique'],...
		'position',[255,230,260,235])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Couple roue'])
set_param([sys,'/','Subsystem/Subsystem1/Couple roue'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[465,205,470,210])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator2']])
set_param([sys,'/',['Subsystem/Subsystem1/Relational',13,'Operator2']],...
		'Operator','<=',...
		'position',[705,571,735,644])

add_block('built-in/Inport',[sys,'/','Subsystem/Subsystem1/in_1'])
set_param([sys,'/','Subsystem/Subsystem1/in_1'],...
		'position',[315,580,335,600])

add_block('built-in/Note',[sys,'/','Subsystem/Subsystem1/Entre de la vitesse de la roue'])
set_param([sys,'/','Subsystem/Subsystem1/Entre de la vitesse de la roue'],...
		'position',[420,555,425,560])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant3'])
set_param([sys,'/','Subsystem/Subsystem1/Constant3'],...
		'Value','rotation_maximale',...
		'position',[535,611,675,639])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem1/t <=debut_desaturation ',13,'=>    0']])
set_param([sys,'/',['Subsystem/Subsystem1/t <=debut_desaturation ',13,'=>    0']],...
		'position',[615,410,620,415])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem1/Constant7'])
set_param([sys,'/','Subsystem/Subsystem1/Constant7'],...
		'Value','debut_desaturation',...
		'position',[535,471,675,509])
add_line([sys,'/','Subsystem/Subsystem1'],[340,590;700,590])
add_line([sys,'/','Subsystem/Subsystem1'],[680,625;700,625])
add_line([sys,'/','Subsystem/Subsystem1'],[680,490;700,490])
add_line([sys,'/','Subsystem/Subsystem1'],[115,310;500,310;500,455;700,455])
add_line([sys,'/','Subsystem/Subsystem1'],[740,610;785,610;785,550;825,550])
add_line([sys,'/','Subsystem/Subsystem1'],[855,515;875,515;875,390;905,390])
add_line([sys,'/','Subsystem/Subsystem1'],[935,360;1035,360])
add_line([sys,'/','Subsystem/Subsystem1'],[955,360;955,460;970,460])
add_line([sys,'/','Subsystem/Subsystem1'],[875,515;995,515])
add_line([sys,'/','Subsystem/Subsystem1'],[240,200;615,200])
add_line([sys,'/','Subsystem/Subsystem1'],[795,400;825,400])
add_line([sys,'/','Subsystem/Subsystem1'],[650,190;815,190;815,325;905,325])
add_line([sys,'/','Subsystem/Subsystem1'],[155,310;155,120;195,120])
add_line([sys,'/','Subsystem/Subsystem1'],[740,475;825,475])
add_line([sys,'/','Subsystem/Subsystem1'],[295,120;310,120])
add_line([sys,'/','Subsystem/Subsystem1'],[415,120;425,120;425,180;615,180])
add_line([sys,'/','Subsystem/Subsystem1'],[425,120;475,120])
add_line([sys,'/','Subsystem/Subsystem1'],[810,635;810,625;825,625])
set_param([sys,'/','Subsystem/Subsystem1'],...
		'Mask Display','BLOC COMMANDE ET ACTION\nDESATURATION')


%     Finished composite block 'Subsystem/Subsystem1'.

set_param([sys,'/','Subsystem/Subsystem1'],...
		'position',[340,269,565,351])

add_block('built-in/Transport Delay',[sys,'/','Subsystem/Retard4'])
set_param([sys,'/','Subsystem/Retard4'],...
		'Delay Time','0.2',...
		'position',[705,294,765,326])

add_block('built-in/Note',[sys,'/',['Subsystem/Le couple de dsaturation',13,'est de dimension 1',13,'sur l''axe tangage']])
set_param([sys,'/',['Subsystem/Le couple de dsaturation',13,'est de dimension 1',13,'sur l''axe tangage']],...
		'position',[745,230,750,235])

add_block('built-in/Transport Delay',[sys,'/','Subsystem/Retard3'])
set_param([sys,'/','Subsystem/Retard3'],...
		'Delay Time','0.2',...
		'position',[615,414,675,446])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre du couple ',13,'sur le satellite']])
set_param([sys,'/',['Subsystem/Entre du couple ',13,'sur le satellite']],...
		'position',[530,410,535,415])

add_block('built-in/Note',[sys,'/',['Subsystem/Reconstruction d''un',13,'couple de dimension 3']])
set_param([sys,'/',['Subsystem/Reconstruction d''un',13,'couple de dimension 3']],...
		'position',[940,500,945,505])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'Value','0',...
		'position',[860,335,880,355])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'Value','0',...
		'position',[860,265,880,285])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux1'])
set_param([sys,'/','Subsystem/Mux1'],...
		'inputs','3',...
		'position',[930,259,975,361])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','3',...
		'position',[935,379,980,481])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant'])
set_param([sys,'/','Subsystem/Constant'],...
		'Value','0',...
		'position',[865,385,885,405])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'Value','0',...
		'position',[865,455,885,475])

add_block('built-in/Note',[sys,'/','Subsystem/Axe tangage N2'])
set_param([sys,'/','Subsystem/Axe tangage N2'],...
		'position',[755,405,760,410])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[1115,420,1135,440])

add_block('built-in/Outport',[sys,'/','Subsystem/out_2'])
set_param([sys,'/','Subsystem/out_2'],...
		'Port','2',...
		'position',[1105,300,1125,320])

add_block('built-in/Note',[sys,'/','Subsystem/DESATURATION'])
set_param([sys,'/','Subsystem/DESATURATION'],...
		'position',[1105,260,1110,265])

add_block('built-in/Note',[sys,'/','Subsystem/ROUE'])
set_param([sys,'/','Subsystem/ROUE'],...
		'position',[1125,470,1130,475])

add_block('built-in/Note',[sys,'/',['Subsystem/Sortie couples',13,'roue et desaturation',13,'dimension 3']])
set_param([sys,'/',['Subsystem/Sortie couples',13,'roue et desaturation',13,'dimension 3']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1110,505,1115,510])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'Gain','30/pi',...
		'position',[765,128,790,162])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[820,130,900,160])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['Subsystem/Vitesse roue',13,'en tours//mn']],...
		'position',[860,95,865,100])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['Subsystem/Vitesse roue ',13,'en rd//s']],...
		'position',[995,140,1000,145])
add_line([sys,'/','Subsystem'],[495,145;760,145])
add_line([sys,'/','Subsystem'],[570,145;570,165])
add_line([sys,'/','Subsystem'],[195,175;265,175;265,75;415,75])
add_line([sys,'/','Subsystem'],[265,145;310,145])
add_line([sys,'/','Subsystem'],[655,145;655,195;920,195])
add_line([sys,'/','Subsystem'],[350,145;380,145])
add_line([sys,'/','Subsystem'],[425,145;440,145])
add_line([sys,'/','Subsystem'],[890,465;930,465])
add_line([sys,'/','Subsystem'],[265,175;265,430;610,430])
add_line([sys,'/','Subsystem'],[985,430;1110,430])
add_line([sys,'/','Subsystem'],[570,310;625,310])
add_line([sys,'/','Subsystem'],[890,395;930,395])
add_line([sys,'/','Subsystem'],[570,205;570,235;305,235;305,290;335,290])
add_line([sys,'/','Subsystem'],[265,330;335,330])
add_line([sys,'/','Subsystem'],[660,310;700,310])
add_line([sys,'/','Subsystem'],[770,310;925,310])
add_line([sys,'/','Subsystem'],[680,430;930,430])
add_line([sys,'/','Subsystem'],[885,345;925,345])
add_line([sys,'/','Subsystem'],[885,275;925,275])
add_line([sys,'/','Subsystem'],[980,310;1100,310])
add_line([sys,'/','Subsystem'],[795,145;815,145])
set_param([sys,'/','Subsystem'],...
		'Mask Display','1- ROUE DE REACTION - COUPLE ROUE\n\n\n\n2- DESATURATION - COUPLE DESATURATION')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[95,204,445,366])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[14,178,1246,820])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,140,35,160])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[700,113,725,137])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux'])
set_param([sys,'/','Subsystem2/Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[465,98,500,207])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum1'])
set_param([sys,'/','Subsystem2/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[410,115,440,190])

add_block('built-in/Note',[sys,'/',['Subsystem2/Entre des angles',13,'roulis et lacet']])
set_param([sys,'/',['Subsystem2/Entre des angles',13,'roulis et lacet']],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[335,55,340,60])

add_block('built-in/Note',[sys,'/','Subsystem2/Consigne-Angles'])
set_param([sys,'/','Subsystem2/Consigne-Angles'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[335,210,340,215])

add_block('built-in/Note',[sys,'/',['Subsystem2/Roulis',13,'lacet']])
set_param([sys,'/',['Subsystem2/Roulis',13,'lacet']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[550,90,555,95])


%     Subsystem  ['Subsystem2/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe x')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe y')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe z')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/',...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem2/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Subsystem2/Champ magntique',13,'en axes satellite']],...
		'position',[275,278,475,352])

add_block('built-in/Note',[sys,'/','Subsystem2/Tangage'])
set_param([sys,'/','Subsystem2/Tangage'],...
		'position',[130,145,135,150])

add_block('built-in/Note',[sys,'/','Subsystem2/Roulis'])
set_param([sys,'/','Subsystem2/Roulis'],...
		'position',[220,115,225,120])

add_block('built-in/Note',[sys,'/',['Subsystem2/Vitesses',13,'inutiles']])
set_param([sys,'/',['Subsystem2/Vitesses',13,'inutiles']],...
		'position',[140,65,145,70])

add_block('built-in/Note',[sys,'/','Subsystem2/Lacet'])
set_param([sys,'/','Subsystem2/Lacet'],...
		'position',[215,200,220,205])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux1'])
set_param([sys,'/','Subsystem2/Mux1'],...
		'inputs','3',...
		'position',[205,274,245,356])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux4'])
set_param([sys,'/','Subsystem2/Demux4'],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[55,70,100,230])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux'])
set_param([sys,'/','Subsystem2/Mux'],...
		'inputs','2',...
		'position',[200,89,245,251])


%     Subsystem  'Subsystem2/UnNamed4'.

new_system([sys,'/','Subsystem2/UnNamed4'])
set_param([sys,'/','Subsystem2/UnNamed4'],'Location',[31,157,323,338])

add_block('built-in/Mux',[sys,'/','Subsystem2/UnNamed4/Mux'])
set_param([sys,'/','Subsystem2/UnNamed4/Mux'],...
		'inputs','2',...
		'position',[175,57,205,133])

add_block('built-in/Outport',[sys,'/','Subsystem2/UnNamed4/out_1'])
set_param([sys,'/','Subsystem2/UnNamed4/out_1'],...
		'position',[240,85,260,105])

add_block('built-in/Constant',[sys,'/','Subsystem2/UnNamed4/Constant3'])
set_param([sys,'/','Subsystem2/UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','consigne_lacet',...
		'position',[25,104,130,126])

add_block('built-in/Constant',[sys,'/','Subsystem2/UnNamed4/Constant1'])
set_param([sys,'/','Subsystem2/UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','consigne_roulis',...
		'position',[25,62,135,88])
add_line([sys,'/','Subsystem2/UnNamed4'],[140,75;170,75])
add_line([sys,'/','Subsystem2/UnNamed4'],[135,115;170,115])
add_line([sys,'/','Subsystem2/UnNamed4'],[210,95;235,95])
set_param([sys,'/','Subsystem2/UnNamed4'],...
		'Mask Display','Consigne\nroulis(1) lacet(2)')


%     Finished composite block 'Subsystem2/UnNamed4'.

set_param([sys,'/','Subsystem2/UnNamed4'],...
		'hide name',0,...
		'position',[290,117,385,153])

add_block('built-in/Note',[sys,'/',['Subsystem2/Sortie roulis(1)',13,'lacet(2)']])
set_param([sys,'/',['Subsystem2/Sortie roulis(1)',13,'lacet(2)']],...
		'position',[335,175,340,180])


%     Subsystem  'Subsystem2/Subsystem2'.

new_system([sys,'/','Subsystem2/Subsystem2'])
set_param([sys,'/','Subsystem2/Subsystem2'],'Location',[4,50,856,463])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain2'],...
		'Gain','gain_roulis',...
		'position',[595,232,620,258])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem2/Subsystem2/Filtre passe bas',13,'roulis']])
set_param([sys,'/',['Subsystem2/Subsystem2/Filtre passe bas',13,'roulis']],...
		'Denominator','[1 1/0.8]',...
		'position',[680,220,740,270])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/Subsystem2/out_1'],...
		'position',[775,235,795,255])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain1'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_ROULIS*5',...
		'position',[445,224,500,266])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/ROUE'])
set_param([sys,'/','Subsystem2/Subsystem2/ROUE'],...
		'hide name',0,...
		'position',[449,170,454,175])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Subsystem2/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[535,137,565,353])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem2/Derivative'])
set_param([sys,'/','Subsystem2/Subsystem2/Derivative'],...
		'position',[365,225,410,265])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem2/Intgrateur'])
set_param([sys,'/','Subsystem2/Subsystem2/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PID_ROULIS]',...
		'Denominator','[1 0]',...
		'position',[350,294,435,336])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Subsystem2/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_ROULIS',...
		'position',[370,156,445,194])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem2/gain 0 ou 1'])
set_param([sys,'/','Subsystem2/Subsystem2/gain 0 ou 1'],...
		'Gain','1/2',...
		'position',[465,302,495,328])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/Rappel proportionnel'])
set_param([sys,'/','Subsystem2/Subsystem2/Rappel proportionnel'],...
		'position',[400,190,405,195])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/roulisref - roulis '])
set_param([sys,'/','Subsystem2/Subsystem2/roulisref - roulis '],...
		'position',[280,135,285,140])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem2/Rappel',13,'proportionnel']])
set_param([sys,'/',['Subsystem2/Subsystem2/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[465,140,470,145])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/Subsystem2/in_1'],...
		'position',[265,165,285,185])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem2/PID ROULIS'])
set_param([sys,'/','Subsystem2/Subsystem2/PID ROULIS'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[510,70,515,75])
add_line([sys,'/','Subsystem2/Subsystem2'],[745,245;770,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[500,315;530,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[440,315;460,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[505,245;530,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[415,245;440,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[450,175;530,175])
add_line([sys,'/','Subsystem2/Subsystem2'],[290,175;365,175])
add_line([sys,'/','Subsystem2/Subsystem2'],[345,175;320,175;320,315;345,315])
add_line([sys,'/','Subsystem2/Subsystem2'],[320,245;360,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[625,245;675,245])
add_line([sys,'/','Subsystem2/Subsystem2'],[570,245;590,245])
set_param([sys,'/','Subsystem2/Subsystem2'],...
		'Mask Display','PID ROULIS SEUL')


%     Finished composite block 'Subsystem2/Subsystem2'.

set_param([sys,'/','Subsystem2/Subsystem2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[525,98,675,152])

add_block('built-in/Fcn',[sys,'/','Subsystem2/Fcn'])
set_param([sys,'/','Subsystem2/Fcn'],...
		'Expr','1/u',...
		'position',[605,305,645,325])

add_block('built-in/Demux',[sys,'/','Subsystem2/Demux1'])
set_param([sys,'/','Subsystem2/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[515,259,560,371])

add_block('built-in/Note',[sys,'/','Subsystem2/B'])
set_param([sys,'/','Subsystem2/B'],...
		'position',[531,270,536,275])

add_block('built-in/Note',[sys,'/','Subsystem2/By'])
set_param([sys,'/','Subsystem2/By'],...
		'position',[585,290,590,295])

add_block('built-in/Product',[sys,'/','Subsystem2/Product3'])
set_param([sys,'/','Subsystem2/Product3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[745,506,775,544])

add_block('built-in/Product',[sys,'/','Subsystem2/Product2'])
set_param([sys,'/','Subsystem2/Product2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[745,416,775,454])

add_block('built-in/Note',[sys,'/','Subsystem2/Champ B axes satellite'])
set_param([sys,'/','Subsystem2/Champ B axes satellite'],...
		'position',[565,375,570,380])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum2'])
set_param([sys,'/','Subsystem2/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[290,515,320,590])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant'])
set_param([sys,'/','Subsystem2/Constant'],...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[145,525,255,545])


%     Subsystem  'Subsystem2/Subsystem4'.

new_system([sys,'/','Subsystem2/Subsystem4'])
set_param([sys,'/','Subsystem2/Subsystem4'],'Location',[274,618,883,973])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/Ecart teta_ref - teta'])
set_param([sys,'/','Subsystem2/Subsystem4/Ecart teta_ref - teta'],...
		'position',[70,40,75,45])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/Rappel proportionnel'])
set_param([sys,'/','Subsystem2/Subsystem4/Rappel proportionnel'],...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/gain 0 ou 1'])
set_param([sys,'/','Subsystem2/Subsystem4/gain 0 ou 1'],...
		'Gain','0',...
		'position',[255,207,285,233])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PD',...
		'position',[160,61,235,99])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem4/in_1'])
set_param([sys,'/','Subsystem2/Subsystem4/in_1'],...
		'position',[55,70,75,90])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem4/Intgrateur'])
set_param([sys,'/','Subsystem2/Subsystem4/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PD]',...
		'Denominator','[1 0]',...
		'position',[155,199,225,241])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem4/Derivative'])
set_param([sys,'/','Subsystem2/Subsystem4/Derivative'],...
		'position',[155,130,200,170])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem4/Sum'])
set_param([sys,'/','Subsystem2/Subsystem4/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem4/ROUE'])
set_param([sys,'/','Subsystem2/Subsystem4/ROUE'],...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain1'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PD',...
		'position',[235,129,290,171])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem4/Filtre passe bas'])
set_param([sys,'/','Subsystem2/Subsystem4/Filtre passe bas'],...
		'Denominator','[1 1/0.8]',...
		'position',[455,125,515,175])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem4/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem4/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','gain_roue',...
		'position',[375,129,430,171])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem4/commande_pid'])
set_param([sys,'/','Subsystem2/Subsystem4/commande_pid'],...
		'position',[555,140,575,160])
add_line([sys,'/','Subsystem2/Subsystem4'],[290,220;320,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[230,220;250,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[295,150;320,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[205,150;230,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[240,80;320,80])
add_line([sys,'/','Subsystem2/Subsystem4'],[80,80;155,80])
add_line([sys,'/','Subsystem2/Subsystem4'],[520,150;550,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[110,80;110,220;150,220])
add_line([sys,'/','Subsystem2/Subsystem4'],[110,150;150,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[360,150;370,150])
add_line([sys,'/','Subsystem2/Subsystem4'],[435,150;450,150])
set_param([sys,'/','Subsystem2/Subsystem4'],...
		'Mask Display','P.I.D TANGAGE')


%     Finished composite block 'Subsystem2/Subsystem4'.

set_param([sys,'/','Subsystem2/Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[370,524,495,586])

add_block('built-in/Note',[sys,'/','Subsystem2/PID teta'])
set_param([sys,'/','Subsystem2/PID teta'],...
		'position',[445,590,450,595])

add_block('built-in/Note',[sys,'/','Subsystem2/REGULATION 2 MAGNECOUPLEURS + 1 ROUE TANGAGE'])
set_param([sys,'/','Subsystem2/REGULATION 2 MAGNECOUPLEURS + 1 ROUE TANGAGE'],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[565,5,570,10])


%     Subsystem  'Subsystem2/Subsystem3'.

new_system([sys,'/','Subsystem2/Subsystem3'])
set_param([sys,'/','Subsystem2/Subsystem3'],'Location',[133,130,823,495])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem3/Rappel',13,'proportionnel1']])
set_param([sys,'/',['Subsystem2/Subsystem3/Rappel',13,'proportionnel1']],...
		'ForeGround',1,...
		'position',[315,75,320,80])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/lacet_ref - lacet  '])
set_param([sys,'/','Subsystem2/Subsystem3/lacet_ref - lacet  '],...
		'position',[125,90,130,95])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/Rappel proportionnel1'])
set_param([sys,'/','Subsystem2/Subsystem3/Rappel proportionnel1'],...
		'position',[245,145,250,150])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/gain 0 ou 2'])
set_param([sys,'/','Subsystem2/Subsystem3/gain 0 ou 2'],...
		'Gain','1*2',...
		'position',[310,257,340,283])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain2'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_LACET*2',...
		'position',[215,111,290,149])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Subsystem3/Intgrateur1'])
set_param([sys,'/','Subsystem2/Subsystem3/Intgrateur1'],...
		'BackGround',7,...
		'Numerator','[I_PID_LACET]',...
		'Denominator','[1 0]',...
		'position',[210,249,280,291])

add_block('built-in/Derivative',[sys,'/','Subsystem2/Subsystem3/Derivative1'])
set_param([sys,'/','Subsystem2/Subsystem3/Derivative1'],...
		'position',[210,180,255,220])

add_block('built-in/Sum',[sys,'/','Subsystem2/Subsystem3/Sum1'])
set_param([sys,'/','Subsystem2/Subsystem3/Sum1'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[380,92,410,308])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/ROUE1'])
set_param([sys,'/','Subsystem2/Subsystem3/ROUE1'],...
		'hide name',0,...
		'position',[294,125,299,130])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain3'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain3'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_LACET*5',...
		'position',[290,179,345,221])

add_block('built-in/Outport',[sys,'/','Subsystem2/Subsystem3/out_1'])
set_param([sys,'/','Subsystem2/Subsystem3/out_1'],...
		'position',[580,190,600,210])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem3/in_1'])
set_param([sys,'/','Subsystem2/Subsystem3/in_1'],...
		'position',[115,120,135,140])

add_block('built-in/Gain',[sys,'/','Subsystem2/Subsystem3/Gain4'])
set_param([sys,'/','Subsystem2/Subsystem3/Gain4'],...
		'Gain','gain_lacet',...
		'position',[440,187,465,213])

add_block('built-in/Transfer Fcn',[sys,'/',['Subsystem2/Subsystem3/Filtre passe bas',13,'lacet']])
set_param([sys,'/',['Subsystem2/Subsystem3/Filtre passe bas',13,'lacet']],...
		'Denominator','[1 1/0.8]',...
		'position',[485,175,545,225])

add_block('built-in/Note',[sys,'/','Subsystem2/Subsystem3/PID LACET'])
set_param([sys,'/','Subsystem2/Subsystem3/PID LACET'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[335,20,340,25])
add_line([sys,'/','Subsystem2/Subsystem3'],[140,130;210,130])
add_line([sys,'/','Subsystem2/Subsystem3'],[190,130;165,130;165,270;205,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[165,200;205,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[295,130;375,130])
add_line([sys,'/','Subsystem2/Subsystem3'],[260,200;285,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[350,200;375,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[285,270;305,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[345,270;375,270])
add_line([sys,'/','Subsystem2/Subsystem3'],[550,200;575,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[470,200;480,200])
add_line([sys,'/','Subsystem2/Subsystem3'],[415,200;435,200])
set_param([sys,'/','Subsystem2/Subsystem3'],...
		'Mask Display','PID LACET SEUL')


%     Finished composite block 'Subsystem2/Subsystem3'.

set_param([sys,'/','Subsystem2/Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[525,158,675,212])

add_block('built-in/Product',[sys,'/','Subsystem2/Product1'])
set_param([sys,'/','Subsystem2/Product1'],...
		'hide name',0,...
		'position',[740,116,770,154])

add_block('built-in/Note',[sys,'/','Subsystem2/1//By'])
set_param([sys,'/','Subsystem2/1//By'],...
		'position',[740,320,745,325])

add_block('built-in/Mux',[sys,'/','Subsystem2/Mux2'])
set_param([sys,'/','Subsystem2/Mux2'],...
		'hide name',0,...
		'inputs','[1 1 1 3]',...
		'position',[945,221,975,324])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/MATLAB Fcn'])
set_param([sys,'/','Subsystem2/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'Mask Display','M vect B',...
		'position',[1005,258,1065,292])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_2'])
set_param([sys,'/','Subsystem2/out_2'],...
		'position',[1165,265,1185,285])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Sum'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[885,403,905,587])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_3'])
set_param([sys,'/','Subsystem2/out_3'],...
		'Port','2',...
		'position',[1160,485,1180,505])

add_block('built-in/Note',[sys,'/',['Subsystem2/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['Subsystem2/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1120,300,1125,305])

add_block('built-in/Note',[sys,'/',['Subsystem2/moment',13,'magn']])
set_param([sys,'/',['Subsystem2/moment',13,'magn']],...
		'position',[965,325,970,330])

add_block('built-in/Note',[sys,'/',['Subsystem2/COUPLE ROUE',13,'DIMENSION 1']])
set_param([sys,'/',['Subsystem2/COUPLE ROUE',13,'DIMENSION 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1125,525,1130,530])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[990,127,1040,143])

add_block('built-in/Note',[sys,'/',['Subsystem2/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['Subsystem2/Moments magntiques',13,'des bobines']],...
		'position',[1015,140,1020,145])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant1'])
set_param([sys,'/','Subsystem2/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[845,250,865,270])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace1'])
set_param([sys,'/','Subsystem2/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[995,187,1045,203])

add_block('built-in/Saturation',[sys,'/','Subsystem2/Saturation1'])
set_param([sys,'/','Subsystem2/Saturation1'],...
		'Lower Limit','-0.2',...
		'Upper Limit','0.2',...
		'position',[800,118,845,152])

add_block('built-in/Saturation',[sys,'/','Subsystem2/Saturation'])
set_param([sys,'/','Subsystem2/Saturation'],...
		'Lower Limit','-0.2',...
		'Upper Limit','0.2',...
		'position',[805,178,850,212])

add_block('built-in/Saturation',[sys,'/','Subsystem2/Saturation2'])
set_param([sys,'/','Subsystem2/Saturation2'],...
		'Lower Limit','-4e-6',...
		'Upper Limit','4e-6',...
		'position',[975,478,1020,512])

add_block('built-in/Note',[sys,'/','Subsystem2/Couple commande sur le tangage'])
set_param([sys,'/','Subsystem2/Couple commande sur le tangage'],...
		'position',[1065,585,1070,590])

add_block('built-in/Note',[sys,'/',['Subsystem2/Limiteur du ',13,'couple roue']])
set_param([sys,'/',['Subsystem2/Limiteur du ',13,'couple roue']],...
		'position',[995,435,1000,440])

add_block('built-in/Note',[sys,'/',['Subsystem2/Limiteurs de',13,'moments magntiques']])
set_param([sys,'/',['Subsystem2/Limiteurs de',13,'moments magntiques']],...
		'position',[830,65,835,70])

add_block('built-in/Note',[sys,'/','Subsystem2/mz'])
set_param([sys,'/','Subsystem2/mz'],...
		'position',[755,95,760,100])

add_block('built-in/Note',[sys,'/','Subsystem2/mx'])
set_param([sys,'/','Subsystem2/mx'],...
		'position',[755,155,760,160])

add_block('built-in/Product',[sys,'/','Subsystem2/Product'])
set_param([sys,'/','Subsystem2/Product'],...
		'hide name',0,...
		'position',[740,176,770,214])
add_line([sys,'/','Subsystem2'],[445,155;460,155])
add_line([sys,'/','Subsystem2'],[390,135;405,135])
add_line([sys,'/','Subsystem2'],[105,130;195,130])
add_line([sys,'/','Subsystem2'],[105,210;195,210])
add_line([sys,'/','Subsystem2'],[250,170;405,170])
add_line([sys,'/','Subsystem2'],[40,150;50,150])
add_line([sys,'/','Subsystem2'],[250,315;270,315])
add_line([sys,'/','Subsystem2'],[175,130;175,290;200,290])
add_line([sys,'/','Subsystem2'],[105,170;145,170;145,315;200,315])
add_line([sys,'/','Subsystem2'],[325,555;365,555])
add_line([sys,'/','Subsystem2'],[260,535;285,535])
add_line([sys,'/','Subsystem2'],[115,210;115,340;200,340])
add_line([sys,'/','Subsystem2'],[130,170;130,570;285,570])
add_line([sys,'/','Subsystem2'],[480,315;510,315])
add_line([sys,'/','Subsystem2'],[505,180;520,185])
add_line([sys,'/','Subsystem2'],[505,125;520,125])
add_line([sys,'/','Subsystem2'],[565,315;600,315])
add_line([sys,'/','Subsystem2'],[680,185;735,185])
add_line([sys,'/','Subsystem2'],[650,315;725,315;735,205])
add_line([sys,'/','Subsystem2'],[680,125;695,125])
add_line([sys,'/','Subsystem2'],[730,125;735,125])
add_line([sys,'/','Subsystem2'],[715,315;715,145;735,145])
add_line([sys,'/','Subsystem2'],[870,260;940,260])
add_line([sys,'/','Subsystem2'],[495,315;495,375;840,375;840,310;940,310])
add_line([sys,'/','Subsystem2'],[980,275;1000,275])
add_line([sys,'/','Subsystem2'],[680,125;680,435;740,435])
add_line([sys,'/','Subsystem2'],[565,280;665,280;665,445;740,445])
add_line([sys,'/','Subsystem2'],[715,315;715,425;740,425])
add_line([sys,'/','Subsystem2'],[715,425;715,515;740,515])
add_line([sys,'/','Subsystem2'],[565,350;645,350;645,535;740,535])
add_line([sys,'/','Subsystem2'],[696,185;695,525;740,525])
add_line([sys,'/','Subsystem2'],[500,555;880,555])
add_line([sys,'/','Subsystem2'],[780,435;880,435])
add_line([sys,'/','Subsystem2'],[780,525;790,525;790,495;880,495])
add_line([sys,'/','Subsystem2'],[1070,275;1160,275])
add_line([sys,'/','Subsystem2'],[775,195;800,195])
add_line([sys,'/','Subsystem2'],[855,195;990,195])
add_line([sys,'/','Subsystem2'],[915,195;915,235;940,235])
add_line([sys,'/','Subsystem2'],[775,135;795,135])
add_line([sys,'/','Subsystem2'],[850,135;985,135])
add_line([sys,'/','Subsystem2'],[890,135;890,285;940,285])
add_line([sys,'/','Subsystem2'],[910,495;970,495])
add_line([sys,'/','Subsystem2'],[1025,495;1155,495])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','4 - COMMANDE 2 AXES ROULIS-LACET\n\nAVEC 2 BOBINES ROULIS-LACET\n\n5 - COMMANDE TANGAGE SEUL PAR ROUE')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[90,460,440,560])

add_block('built-in/Note',[sys,'/','Retour du couple roue'])
set_param([sys,'/','Retour du couple roue'],...
		'position',[175,565,180,570])

add_block('built-in/Note',[sys,'/',['Retour d''tat']])
set_param([sys,'/',['Retour d''tat']],...
		'position',[160,630,165,635])

add_block('built-in/Note',[sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'])
set_param([sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[395,630,400,635])

add_block('built-in/Note',[sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']])
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'ForeGround',4)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Name','Arial')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Weight','bold')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Size',14)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//regdesat.m  initialise  chaque simulation  ',13,'par  nom lecteur://......//scadesat.m ( opration double click avant dpart de la simulation )',13,' ']],...
		'position',[525,670,530,675])

add_block('built-in/Note',[sys,'/','(Avec les quations TMC Garino-Guiziou )'])
set_param([sys,'/','(Avec les quations TMC Garino-Guiziou )'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[730,630,735,635])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',2,...
		'BackGround',7,...
		'position',[45,58,120,132])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir la courbe\n\ncouple roue(Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;gcf'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[45,835,220,896])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir la courbe\n\nenergie(J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;gcf'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[50,750,225,811])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'position',[630,525,635,530])

add_block('built-in/State-Space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','A_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT,vitesseroue)',...
		'B','B_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT)',...
		'C','eye(6)',...
		'D','zeros(6,3)')
set_param([sys,'/','State-space'],...
		'X0','[0 0 0 0.1 -0.1 -0.05]''',...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[745,338,860,392])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\n\nmoments magntiques(Am)',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;gcf'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[500,745,730,806])

add_block('built-in/Note',[sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']])
set_param([sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']],...
		'Font Name','Arial')
set_param([sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']],...
		'Font Weight','bold')
set_param([sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']],...
		'Font Angle','italic')
set_param([sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']],...
		'Font Size',14)
set_param([sys,'/',['Attention: la simulation est',13,'contrle par un STOP rglable',13,'dans scadesat.m.',13,' ',13,'',13,'',13,'Ce STOP est',13,'mis automatiquement hors service',13,'en dsaturation']],...
		'position',[1100,690,1105,695])

add_block('built-in/Note',[sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']])
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18)
set_param([sys,'/',['SYNTHESE DE TOUTES LES POSSIBILITES DE COMMANDES ET DE CAS',13,'(  1 roue axe tangage + 2 magntocoupleurs axes roulis lacet )']],...
		'position',[585,45,590,50])

add_block('built-in/Note',[sys,'/',['SUIVRE L''ORDRE',13,' 1 ou 2 puis 3']])
set_param([sys,'/',['SUIVRE L''ORDRE',13,' 1 ou 2 puis 3']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Angle','italic',...
		'Font Size',22,...
		'position',[1100,120,1105,125])


%     Subsystem  'Extras3'.

new_system([sys,'/','Extras3'])
set_param([sys,'/','Extras3'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras3'],...
		'Mask Display','Avec dsaturation\n\n1\n\ndouble clic souris',...
		'Mask Dialogue','eval(''desat=1,reponse=1,'')')


%     Finished composite block 'Extras3'.

set_param([sys,'/','Extras3'],...
		'ForeGround',4,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1010,220,1180,326])

add_block('built-in/Note',[sys,'/',['CHOIX SIMULATION ',13,'AVEC OU SANS ',13,'DESATURATION']])
set_param([sys,'/',['CHOIX SIMULATION ',13,'AVEC OU SANS ',13,'DESATURATION']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1095,330,1100,335])


%     Subsystem  'Extras4'.

new_system([sys,'/','Extras4'])
set_param([sys,'/','Extras4'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras4'],...
		'Mask Display','Sans dsaturation\n\n2\n\ndouble clic souris',...
		'Mask Dialogue','eval(''desat=0;reponse=0;'')')


%     Finished composite block 'Extras4'.

set_param([sys,'/','Extras4'],...
		'ForeGround',4,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1015,395,1195,496])

add_block('built-in/Note',[sys,'/','Puis -> simulation -> start'])
set_param([sys,'/','Puis -> simulation -> start'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1125,615,1130,620])

add_block('built-in/Note',[sys,'/',['1 + 3',13,'',13,'ou',13,'',13,'2 + 3']])
set_param([sys,'/',['1 + 3',13,'',13,'ou',13,'',13,'2 + 3']],...
		'ForeGround',6,...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[965,515,970,520])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\n\n3\n\nar double clic souris',...
		'Mask Dialogue','eval(''scadesat'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1005,505,1205,606])
add_line(sys,[735,365;740,365])
add_line(sys,[660,365;690,365])
add_line(sys,[450,405;505,405])
add_line(sys,[540,245;605,245])
add_line(sys,[675,365;675,220;715,220])
add_line(sys,[450,245;495,245])
add_line(sys,[865,365;890,365;890,320;695,320;695,275;715,275])
add_line(sys,[445,485;505,485])
add_line(sys,[445,535;495,535;495,590;55,590;55,285;90,285])
add_line(sys,[890,365;890,630;30,630;30,405;90,405])
add_line(sys,[550,485;605,485])
add_line(sys,[550,405;605,405])
add_line(sys,[450,325;505,325])
add_line(sys,[550,325;605,325])
add_line(sys,[30,510;85,510])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
